@@ -1,4 +1,8 @@
 # -*- coding: utf-8 -*-
+import warnings
+
+from statsmodels.compat.pandas import PD_LT_1_4
+
 
 import os
 
@@ -211,7 +215,14 @@ def test_getframe_smoke():
     assert_(isinstance(df, pd.DataFrame))
 
     lds = res.get_loadings_frame(style='strings', decimals=3, threshold=0.3)
-    lds.to_latex()
+    # Old implementation that warns
+    if PD_LT_1_4:
+        with warnings.catch_warnings():
+            warnings.simplefilter("always")
+            lds.to_latex()
+    else:
+        # Smoke test using new style to_latex
+        lds.style.to_latex()
 
     # The Styler option require jinja2, skip if not available
     try:
@@ -220,6 +231,14 @@ def test_getframe_smoke():
         return
         # TODO: separate this and do pytest.skip?
 
+    # Old implementation that warns
+    if PD_LT_1_4:
+        with warnings.catch_warnings():
+            warnings.simplefilter("always")
+            lds.to_latex()
+    else:
+        # Smoke test using new style to_latex
+        lds.style.to_latex()
     try:
         from pandas.io import formats as pd_formats
     except ImportError:
