@@ -25,13 +25,15 @@ sampled.  In general the observed units are independent and
 identically distributed.
 """
 
-from statsmodels.tools.decorators import cache_readonly
-import numpy as np
-from scipy import stats
-import pandas as pd
 import warnings
+
+import numpy as np
+import pandas as pd
+from scipy import stats
+
 from statsmodels import iolib
 from statsmodels.tools import sm_exceptions
+from statsmodels.tools.decorators import cache_readonly
 
 
 def _make_df_square(table):
@@ -56,7 +58,7 @@ def _make_df_square(table):
     return table
 
 
-class _Bunch(object):
+class _Bunch:
 
     def __repr__(self):
         return "<bunch containing results, print to see contents>"
@@ -72,7 +74,7 @@ class _Bunch(object):
         return "\n".join(tab)
 
 
-class Table(object):
+class Table:
     """
     A two-way contingency table.
 
@@ -439,6 +441,8 @@ class SquareTable(Table):
         If True and any cell count is zero, add 0.5 to all values
         in the table.
 
+    Notes
+    -----
     These methods should only be used when the rows and columns of the
     table have the same categories.  If `table` is provided as a
     Pandas DataFrame, the row and column indices will be extended to
@@ -469,14 +473,15 @@ class SquareTable(Table):
 
         Returns
         -------
-        A bunch with attributes:
+        Bunch
+            A bunch with attributes
 
-        statistic : float
-            chisquare test statistic
-        p-value : float
-            p-value of the test statistic based on chisquare distribution
-        df : int
-            degrees of freedom of the chisquare distribution
+            * statistic : float
+                chisquare test statistic
+            * p-value : float
+                p-value of the test statistic based on chisquare distribution
+            * df : int
+                degrees of freedom of the chisquare distribution
 
         Notes
         -----
@@ -527,14 +532,17 @@ class SquareTable(Table):
             estimates of the covariance matrix for the estimated
             difference between the row margins and the column margins.
 
-        Returns a bunch with attributes:
+        Returns
+        -------
+        Bunch
+            A bunch with attributes:
 
-        statistic : float
-            The chi^2 test statistic
-        pvalue : float
-            The p-value of the test statistic
-        df : int
-            The degrees of freedom of the reference distribution
+            * statistic : float
+                The chi^2 test statistic
+            * pvalue : float
+                The p-value of the test statistic
+            * df : int
+                The degrees of freedom of the reference distribution
 
         Notes
         -----
@@ -911,7 +919,7 @@ class Table2x2(SquareTable):
         return tab
 
 
-class StratifiedTable(object):
+class StratifiedTable:
     """
     Analyses for a collection of 2x2 contingency tables.
 
@@ -939,7 +947,7 @@ class StratifiedTable(object):
             sp = tables.shape
             if (len(sp) != 3) or (sp[0] != 2) or (sp[1] != 2):
                 raise ValueError("If an ndarray, argument must be 2x2xn")
-            table = tables
+            table = tables * 1.  # use atleast float dtype
         else:
             if any([np.asarray(x).shape != (2, 2) for x in tables]):
                 m = "If `tables` is a list, all of its elements should be 2x2"
@@ -996,15 +1004,15 @@ class StratifiedTable(object):
 
         Returns
         -------
-        A StratifiedTable instance.
+        StratifiedTable
         """
 
         if not isinstance(data, pd.DataFrame):
             data1 = pd.DataFrame(index=np.arange(data.shape[0]),
                                  columns=[var1, var2, strata])
-            data1.loc[:, var1] = data[:, var1]
-            data1.loc[:, var2] = data[:, var2]
-            data1.loc[:, strata] = data[:, strata]
+            data1[data1.columns[var1]] = data[:, var1]
+            data1[data1.columns[var2]] = data[:, var2]
+            data1[data1.columns[strata]] = data[:, strata]
         else:
             data1 = data[[var1, var2, strata]]
 
@@ -1034,7 +1042,8 @@ class StratifiedTable(object):
 
         Returns
         -------
-        A bunch containing the chi^2 test statistic and p-value.
+        Bunch
+            A bunch containing the chi^2 test statistic and p-value.
         """
 
         statistic = np.sum(self.table[0, 0, :] -
@@ -1089,13 +1098,6 @@ class StratifiedTable(object):
         rr = np.sum(acd / self._n) / np.sum(cab / self._n)
         return rr
 
-    @cache_readonly
-    def risk_pooled(self):
-        # Deprecated due to name being misleading
-        msg = "'risk_pooled' is deprecated, use 'riskratio_pooled' instead"
-        warnings.warn(msg, DeprecationWarning)
-        return self.riskratio_pooled
-
     @cache_readonly
     def logodds_pooled_se(self):
         """
@@ -1336,9 +1338,9 @@ def mcnemar(table, exact=True, correction=True):
         # SciPy 1.7+ requires int arguments
         int_sum = int(n1 + n2)
         if int_sum != (n1 + n2):
-            warnings.warn("exact can only be used with tables containing "
-                          "integers. This warning will become a ValueError "
-                          "after 0.12.", FutureWarning)
+            raise ValueError(
+                "exact can only be used with tables containing integers."
+            )
         pvalue = stats.binom.cdf(statistic, int_sum, 0.5) * 2
         pvalue = np.minimum(pvalue, 1)  # limit to 1 if n1==n2
     else:
