@@ -6,22 +6,17 @@ References
 ----------
 Lütkepohl (2005) New Introduction to Multiple Time Series Analysis
 """
-from __future__ import print_function, division
-
 import numpy as np
 import numpy.linalg as npl
 from numpy.linalg import slogdet
 
-from statsmodels.compat.python import range
-from statsmodels.compat.pandas import deprecate_kwarg
-
+from statsmodels.tsa.tsatools import rename_trend
 from statsmodels.tools.decorators import deprecated_alias
-from statsmodels.tools.numdiff import approx_hess, approx_fprime
-from statsmodels.tsa.vector_ar.irf import IRAnalysis
-from statsmodels.tsa.vector_ar.var_model import VARProcess, VARResults
-
-import statsmodels.tsa.vector_ar.util as util
+from statsmodels.tools.numdiff import approx_fprime, approx_hess
 import statsmodels.tsa.base.tsa_model as tsbase
+from statsmodels.tsa.vector_ar.irf import IRAnalysis
+import statsmodels.tsa.vector_ar.util as util
+from statsmodels.tsa.vector_ar.var_model import VARProcess, VARResults
 
 
 def svar_ckerr(svar_type, A, B):
@@ -40,17 +35,17 @@ class SVAR(tsbase.TimeSeriesModel):
 
     Parameters
     ----------
-    endog : array-like
+    endog : array_like
         1-d endogenous response variable. The independent variable.
-    dates : array-like
+    dates : array_like
         must match number of rows of endog
     svar_type : str
         "A" - estimate structural parameters of A matrix, B assumed = I
         "B" - estimate structural parameters of B matrix, A assumed = I
         "AB" - estimate structural parameters indicated in both A and B matrix
-    A : array-like
+    A : array_like
         neqs x neqs with unknown parameters marked with 'E' for estimate
-    B : array-like
+    B : array_like
         neqs x neqs with unknown parameters marked with 'E' for estimate
 
     References
@@ -62,7 +57,7 @@ class SVAR(tsbase.TimeSeriesModel):
 
     def __init__(self, endog, svar_type, dates=None,
                  freq=None, A=None, B=None, missing='none'):
-        super(SVAR, self).__init__(endog, None, dates, freq, missing=missing)
+        super().__init__(endog, None, dates, freq, missing=missing)
         #(self.endog, self.names,
         # self.dates) = data_util.interpret_data(endog, names, dates)
 
@@ -109,7 +104,7 @@ class SVAR(tsbase.TimeSeriesModel):
 
         #LikelihoodModel.__init__(self, endog)
 
-        #super(SVAR, self).__init__(endog)
+        #super().__init__(endog)
 
     def fit(self, A_guess=None, B_guess=None, maxlags=None, method='ols',
             ic=None, trend='c', verbose=False, s_method='mle',
@@ -119,10 +114,10 @@ class SVAR(tsbase.TimeSeriesModel):
 
         Parameters
         ----------
-        A_guess : array-like, optional
+        A_guess : array_like, optional
             A vector of starting values for all parameters to be estimated
             in A.
-        B_guess : array-like, optional
+        B_guess : array_like, optional
             A vector of starting values for all parameters to be estimated
             in B.
         maxlags : int
@@ -138,11 +133,11 @@ class SVAR(tsbase.TimeSeriesModel):
             bic : Bayesian a.k.a. Schwarz
         verbose : bool, default False
             Print order selection output to the screen
-        trend, str {"c", "ct", "ctt", "nc"}
+        trend, str {"c", "ct", "ctt", "n"}
             "c" - add constant
             "ct" - constant and trend
             "ctt" - constant, linear and quadratic trend
-            "nc" - co constant, no trend
+            "n" - co constant, no trend
             Note that these are prepended to the columns of the dataset.
         s_method : {'mle'}
             Estimation method for structural parameters
@@ -167,7 +162,7 @@ class SVAR(tsbase.TimeSeriesModel):
         est : SVARResults
         """
         lags = maxlags
-
+        trend = rename_trend(trend)
         if ic is not None:
             selections = self.select_order(maxlags=maxlags, verbose=verbose)
             if ic not in selections:
@@ -224,7 +219,7 @@ class SVAR(tsbase.TimeSeriesModel):
                        trend='c', solver="nm", override=False):
         """
         lags : int
-        trend : string or None
+        trend : {str, None}
             As per above
         """
         k_trend = util.get_trendorder(trend)
@@ -255,8 +250,7 @@ class SVAR(tsbase.TimeSeriesModel):
 
         A, B = self._solve_AB(start_params, override=override,
                               solver=solver,
-                              maxiter=maxiter,
-                              maxfun=maxfun)
+                              maxiter=maxiter)
         A_mask = self.A_mask
         B_mask = self.B_mask
 
@@ -276,7 +270,7 @@ class SVAR(tsbase.TimeSeriesModel):
         is estimated
         """
 
-        #TODO: this doesn't look robust if A or B is None
+        #TODO: this does not look robust if A or B is None
         A = self.A
         B = self.B
         A_mask = self.A_mask
@@ -326,8 +320,7 @@ class SVAR(tsbase.TimeSeriesModel):
         loglike = self.loglike
         return approx_hess(AB_mask, loglike)
 
-    def _solve_AB(self, start_params, maxiter, maxfun, override=False,
-                  solver='bfgs'):
+    def _solve_AB(self, start_params, maxiter, override=False, solver='bfgs'):
         """
         Solves for MLE estimate of structural parameters
 
@@ -343,13 +336,10 @@ class SVAR(tsbase.TimeSeriesModel):
             conjugate, 'ncg' (non-conjugate gradient), and 'powell'.
         maxiter : int, optional
             The maximum number of iterations. Default is 500.
-        maxfun : int, optional
-            The maximum number of function evalutions.
 
         Returns
         -------
         A_solve, B_solve: ML solutions for A, B matrices
-
         """
         #TODO: this could stand a refactor
         A_mask = self.A_mask
@@ -368,10 +358,9 @@ class SVAR(tsbase.TimeSeriesModel):
         else: #TODO: change to a warning?
             print("Order/rank conditions have not been checked")
 
-        retvals = super(SVAR, self).fit(start_params=start_params,
-                                        method=solver, maxiter=maxiter,
-                                        maxfun=maxfun, ftol=1e-20,
-                                        disp=0).params
+        retvals = super().fit(start_params=start_params,
+                              method=solver, maxiter=maxiter,
+                              gtol=1e-20, disp=False).params
 
         A[A_mask] = retvals[:A_len]
         B[B_mask] = retvals[A_len:]
@@ -480,7 +469,6 @@ class SVARProcess(VARProcess):
         """
 
         Unavailable for SVAR
-
         """
         raise NotImplementedError
 
@@ -489,7 +477,6 @@ class SVARProcess(VARProcess):
 
         Compute Structural MA coefficient matrices using MLE
         of A, B
-
         """
         if P is None:
             A_solve = self.A_solve
@@ -506,14 +493,14 @@ class SVARResults(SVARProcess, VARResults):
 
     Parameters
     ----------
-    endog : array
-    endog_lagged : array
-    params : array
-    sigma_u : array
+    endog : ndarray
+    endog_lagged : ndarray
+    params : ndarray
+    sigma_u : ndarray
     lag_order : int
     model : VAR model instance
-    trend : str {'nc', 'c', 'ct'}
-    names : array-like
+    trend : str {'n', 'c', 'ct'}
+    names : array_like
         List of names of the endogenous variables in order of appearance in `endog`.
     dates
 
@@ -559,16 +546,10 @@ class SVARResults(SVARProcess, VARResults):
     stderr
     trenorder
     tvalues
-    y :
-    ys_lagged
     """
 
     _model_type = 'SVAR'
 
-    y = deprecated_alias("y", "endog", remove_version="0.11.0")
-    ys_lagged = deprecated_alias("ys_lagged", "endog_lagged",
-                                 remove_version="0.11.0")
-
     def __init__(self, endog, endog_lagged, params, sigma_u, lag_order,
                  A=None, B=None, A_mask=None, B_mask=None, model=None,
                  trend='c', names=None, dates=None):
@@ -602,14 +583,14 @@ class SVARResults(SVARProcess, VARResults):
         coefs = reshaped.swapaxes(1, 2).copy()
 
         #SVAR components
-        #TODO: if you define these here, you don't also have to define
+        #TODO: if you define these here, you do not also have to define
         #them in SVAR process, but I left them for now -ss
         self.A = A
         self.B = B
         self.A_mask = A_mask
         self.B_mask = B_mask
 
-        super(SVARResults, self).__init__(coefs, intercept, sigma_u, A, B,
+        super().__init__(coefs, intercept, sigma_u, A, B,
                                           names=names)
 
     def irf(self, periods=10, var_order=None):
@@ -630,7 +611,6 @@ class SVARResults(SVARProcess, VARResults):
 
         return IRAnalysis(self, P=P, periods=periods, svar=True)
 
-    @deprecate_kwarg('T', 'steps')
     def sirf_errband_mc(self, orth=False, repl=1000, steps=10,
                         signif=0.05, seed=None, burn=100, cum=False):
         """
@@ -639,19 +619,19 @@ class SVARResults(SVARProcess, VARResults):
 
         Parameters
         ----------
-        orth: bool, default False
+        orth : bool, default False
             Compute orthogonalized impulse response error bands
-        repl: int
+        repl : int
             number of Monte Carlo replications to perform
-        steps: int, default 10
+        steps : int, default 10
             number of impulse response periods
-        signif: float (0 < signif <1)
+        signif : float (0 < signif <1)
             Significance level for error bars, defaults to 95% CI
-        seed: int
+        seed : int
             np.random.seed for replications
-        burn: int
+        burn : int
             number of initial observations to discard for simulation
-        cum: bool, default False
+        cum : bool, default False
             produce cumulative irf error bands
 
         Notes
@@ -661,7 +641,6 @@ class SVARResults(SVARProcess, VARResults):
         Returns
         -------
         Tuple of lower and upper arrays of ma_rep monte carlo standard errors
-
         """
         neqs = self.neqs
         mean = self.mean()
