@@ -1,13 +1,18 @@
+from statsmodels.compat.pytest import pytest_warns
 
 import numpy as np
 from numpy.testing import assert_, assert_allclose, assert_raises
 
 import statsmodels.datasets.macrodata.data as macro
-from statsmodels.tsa.vector_ar.tests.JMulTi_results.parse_jmulti_vecm_output \
-    import sublists
+from statsmodels.tsa.vector_ar.tests.JMulTi_results.parse_jmulti_vecm_output import (
+    sublists,
+)
 from statsmodels.tsa.vector_ar.var_model import VAR
-from .JMulTi_results.parse_jmulti_var_output import dt_s_tup_to_string
-from .JMulTi_results.parse_jmulti_var_output import load_results_jmulti
+
+from .JMulTi_results.parse_jmulti_var_output import (
+    dt_s_tup_to_string,
+    load_results_jmulti,
+)
 
 atol = 0.001  # absolute tolerance
 rtol = 0.01  # relative tolerance
@@ -20,12 +25,23 @@ debug_mode = False
 dont_test_se_t_p = False
 deterministic_terms_list = ["nc", "c", "ct"]
 seasonal_list = [0, 4]
-dt_s_list = [(det, s) for det in deterministic_terms_list
-             for s in seasonal_list]
-all_tests = ["coefs", "det", "Sigma_u", "log_like", "fc", "causality",
-             "impulse-response", "lag order", "test normality", "whiteness",
-             "exceptions"]
-to_test = all_tests  #["coefs", "det", "Sigma_u", "log_like", "fc", "causality"]  # all_tests
+dt_s_list = [
+    (det, s) for det in deterministic_terms_list for s in seasonal_list
+]
+all_tests = [
+    "coefs",
+    "det",
+    "Sigma_u",
+    "log_like",
+    "fc",
+    "causality",
+    "impulse-response",
+    "lag order",
+    "test normality",
+    "whiteness",
+    "exceptions",
+]
+to_test = all_tests  # ["coefs", "det", "Sigma_u", "log_like", "fc", "causality"]  # all_tests
 
 
 def load_data(dataset, data_dict):
@@ -62,11 +78,9 @@ def reorder_jmultis_det_terms(jmulti_output, constant, seasons):
         return jmulti_output
     constant = int(constant)
     const_column = jmulti_output[:, :constant]
-    season_columns = jmulti_output[:, constant:constant+seasons-1].copy()
-    trend_columns = jmulti_output[:, constant+seasons-1:].copy()
-    return np.hstack((const_column,
-                      trend_columns,
-                      season_columns))
+    season_columns = jmulti_output[:, constant : constant + seasons - 1].copy()
+    trend_columns = jmulti_output[:, constant + seasons - 1 :].copy()
+    return np.hstack((const_column, trend_columns, season_columns))
 
 
 def generate_exog_from_season(seasons, endog_len):
@@ -117,9 +131,13 @@ def load_results_statsmodels(dataset):
     for dt_s_tup in dt_s_list:
         endog = data[dataset]
         exog = generate_exog_from_season(dt_s_tup[1], len(endog))
+        warn_typ = FutureWarning if dt_s_tup[0] == "nc" else None
+
         model = VAR(endog, exog)
-        results_per_deterministic_terms[dt_s_tup] = model.fit(
-                maxlags=4, trend=dt_s_tup[0], method="ols")
+        with pytest_warns(warn_typ):
+            results_per_deterministic_terms[dt_s_tup] = model.fit(
+                maxlags=4, trend=dt_s_tup[0], method="ols"
+            )
     return results_per_deterministic_terms
 
 
@@ -129,7 +147,7 @@ def build_err_msg(ds, dt_s, parameter_str):
     err_msg = "Error in " + parameter_str + " for:\n"
     err_msg += "- Dataset: " + ds.__str__() + "\n"
     err_msg += "- Deterministic terms: "
-    err_msg += (dt_s[0] if dt != "nc" else "no det. terms")
+    err_msg += dt_s[0] if dt != "nc" else "no det. terms"
     if seasons > 0:
         err_msg += ", seasons: " + str(seasons)
     return err_msg
@@ -167,15 +185,21 @@ def test_ols_coefs():
             # standard errors
             obt = results_sm[ds][dt_s].stderr_endog_lagged
             des = results_ref[ds][dt_s]["se"]["Lagged endogenous term"].T
-            assert_allclose(obt, des, rtol, atol, False, "STANDARD ERRORS\n" + err_msg)
+            assert_allclose(
+                obt, des, rtol, atol, False, "STANDARD ERRORS\n" + err_msg
+            )
             # t-values
             obt = results_sm[ds][dt_s].tvalues_endog_lagged
             des = results_ref[ds][dt_s]["t"]["Lagged endogenous term"].T
-            assert_allclose(obt, des, rtol, atol, False, "t-VALUES\n" + err_msg)
+            assert_allclose(
+                obt, des, rtol, atol, False, "t-VALUES\n" + err_msg
+            )
             # p-values
             obt = results_sm[ds][dt_s].pvalues_endog_lagged
             des = results_ref[ds][dt_s]["p"]["Lagged endogenous term"].T
-            assert_allclose(obt, des, rtol, atol, False, "p-VALUES\n" + err_msg)
+            assert_allclose(
+                obt, des, rtol, atol, False, "p-VALUES\n" + err_msg
+            )
 
 
 def test_ols_det_terms():
@@ -192,36 +216,51 @@ def test_ols_det_terms():
             det_key_ref = "Deterministic term"
             # If there are no det. terms, just make sure we do not compute any:
             if det_key_ref not in results_ref[ds][dt_s]["est"].keys():
-                assert_((results_sm[ds][dt_s].coefs_exog.size == 0 and
-                         results_sm[ds][dt_s].stderr_dt.size == 0 and
-                         results_sm[ds][dt_s].tvalues_dt.size == 0 and
-                         results_sm[ds][dt_s].pvalues_dt.size == 0), err_msg)
+                assert_(
+                    (
+                        results_sm[ds][dt_s].coefs_exog.size == 0
+                        and results_sm[ds][dt_s].stderr_dt.size == 0
+                        and results_sm[ds][dt_s].tvalues_dt.size == 0
+                        and results_sm[ds][dt_s].pvalues_dt.size == 0
+                    ),
+                    err_msg,
+                )
                 continue
             obtained = results_sm[ds][dt_s].coefs_exog
             desired = results_ref[ds][dt_s]["est"][det_key_ref]
             desired = reorder_jmultis_det_terms(
-                    desired, dt_s[0].startswith("c"), dt_s[1])
+                desired, dt_s[0].startswith("c"), dt_s[1]
+            )
             assert_allclose(obtained, desired, rtol, atol, False, err_msg)
             if debug_mode and dont_test_se_t_p:
                 continue
             # standard errors
             obt = results_sm[ds][dt_s].stderr_dt
             des = results_ref[ds][dt_s]["se"][det_key_ref]
-            des = reorder_jmultis_det_terms(des, dt_s[0].startswith("c"),
-                                            dt_s[1]).T
-            assert_allclose(obt, des, rtol, atol, False, "STANDARD ERRORS\n" + err_msg)
+            des = reorder_jmultis_det_terms(
+                des, dt_s[0].startswith("c"), dt_s[1]
+            ).T
+            assert_allclose(
+                obt, des, rtol, atol, False, "STANDARD ERRORS\n" + err_msg
+            )
             # t-values
             obt = results_sm[ds][dt_s].tvalues_dt
             des = results_ref[ds][dt_s]["t"][det_key_ref]
-            des = reorder_jmultis_det_terms(des, dt_s[0].startswith("c"),
-                                            dt_s[1]).T
-            assert_allclose(obt, des, rtol, atol, False, "t-VALUES\n" + err_msg)
+            des = reorder_jmultis_det_terms(
+                des, dt_s[0].startswith("c"), dt_s[1]
+            ).T
+            assert_allclose(
+                obt, des, rtol, atol, False, "t-VALUES\n" + err_msg
+            )
             # p-values
             obt = results_sm[ds][dt_s].pvalues_dt
             des = results_ref[ds][dt_s]["p"][det_key_ref]
-            des = reorder_jmultis_det_terms(des, dt_s[0].startswith("c"),
-                                            dt_s[1]).T
-            assert_allclose(obt, des, rtol, atol, False, "p-VALUES\n" + err_msg)
+            des = reorder_jmultis_det_terms(
+                des, dt_s[0].startswith("c"), dt_s[1]
+            ).T
+            assert_allclose(
+                obt, des, rtol, atol, False, "p-VALUES\n" + err_msg
+            )
 
 
 def test_ols_sigma():
@@ -269,28 +308,33 @@ def test_fc():
                 print("\n" + dt_s_tup_to_string(dt) + ": ", end="")
             steps = 5  # parsed JMulTi output comprises 5 steps
             last_observations = results_sm[ds][dt].endog[
-                -results_sm[ds][dt].k_ar:]
+                -results_sm[ds][dt].k_ar :
+            ]
             seasons = dt[1]
             if seasons == 0:
                 exog_future = None
             else:
-                exog_future = np.zeros((steps, seasons-1))
+                exog_future = np.zeros((steps, seasons - 1))
                 # the following line is appropriate only if the last
                 # observation was in the next to last season (this is the case
                 # for macrodata)
-                exog_future[1:seasons] = np.identity(seasons-1)
+                exog_future[1:seasons] = np.identity(seasons - 1)
             err_msg = build_err_msg(ds, dt, "FORECAST")
             # test point forecast functionality of forecast method
             obtained = results_sm[ds][dt].forecast(
-                y=last_observations, steps=steps, exog_future=exog_future)
+                y=last_observations, steps=steps, exog_future=exog_future
+            )
             desired = results_ref[ds][dt]["fc"]["fc"]
             assert_allclose(obtained, desired, rtol, atol, False, err_msg)
 
             # test forecast method with confidence interval calculation
             err_msg = build_err_msg(ds, dt, "FORECAST WITH INTERVALS")
             obtained = results_sm[ds][dt].forecast_interval(
-                y=last_observations, steps=steps, alpha=0.05,
-                exog_future=exog_future)
+                y=last_observations,
+                steps=steps,
+                alpha=0.05,
+                exog_future=exog_future,
+            )
             obt = obtained[0]  # forecast
             obt_l = obtained[1]  # lower bound
             obt_u = obtained[2]  # upper bound
@@ -318,105 +362,181 @@ def test_causality():  # test Granger- and instantaneous causality
             err_msg_i_p = build_err_msg(ds, dt, "INSTANT. CAUS. - p-VALUE")
             err_msg_i_t = build_err_msg(ds, dt, "INSTANT. CAUS. - TEST STAT.")
             v_ind = range(len(ds.variable_names))
-            for causing_ind in sublists(v_ind, 1, len(v_ind)-1):
-                causing_names = ["y" + str(i+1) for i in causing_ind]
+            for causing_ind in sublists(v_ind, 1, len(v_ind) - 1):
+                causing_names = ["y" + str(i + 1) for i in causing_ind]
                 causing_key = tuple(ds.variable_names[i] for i in causing_ind)
 
                 caused_ind = [i for i in v_ind if i not in causing_ind]
-                caused_names = ["y" + str(i+1) for i in caused_ind]
+                caused_names = ["y" + str(i + 1) for i in caused_ind]
                 caused_key = tuple(ds.variable_names[i] for i in caused_ind)
 
                 # test Granger-causality ######################################
-                granger_sm_ind = results_sm[ds][
-                    dt].test_causality(caused_ind, causing_ind)
-                granger_sm_str = results_sm[ds][
-                    dt].test_causality(caused_names, causing_names)
+                granger_sm_ind = results_sm[ds][dt].test_causality(
+                    caused_ind, causing_ind
+                )
+                granger_sm_str = results_sm[ds][dt].test_causality(
+                    caused_names, causing_names
+                )
 
                 # test test-statistic for Granger non-causality:
                 g_t_obt = granger_sm_ind.test_statistic
-                g_t_des = results_ref[ds][dt]["granger_caus"][
-                    "test_stat"][(causing_key, caused_key)]
-                assert_allclose(g_t_obt, g_t_des, rtol, atol, False, err_msg_g_t)
+                g_t_des = results_ref[ds][dt]["granger_caus"]["test_stat"][
+                    (causing_key, caused_key)
+                ]
+                assert_allclose(
+                    g_t_obt, g_t_des, rtol, atol, False, err_msg_g_t
+                )
                 # check whether string sequences as args work in the same way:
                 g_t_obt_str = granger_sm_str.test_statistic
-                assert_allclose(g_t_obt_str, g_t_obt, 1e-07, 0, False,
-                                err_msg_g_t + " - sequences of integers and ".upper() +
-                                "strings as arguments do not yield the same result!".upper())
+                assert_allclose(
+                    g_t_obt_str,
+                    g_t_obt,
+                    1e-07,
+                    0,
+                    False,
+                    err_msg_g_t
+                    + " - sequences of integers and ".upper()
+                    + "strings as arguments do not yield the same result!".upper(),
+                )
                 # check if int (e.g. 0) as index and list of int ([0]) yield
                 # the same result:
                 if len(causing_ind) == 1 or len(caused_ind) == 1:
-                    ci = causing_ind[0] if len(causing_ind)==1 else causing_ind
+                    ci = (
+                        causing_ind[0]
+                        if len(causing_ind) == 1
+                        else causing_ind
+                    )
                     ce = caused_ind[0] if len(caused_ind) == 1 else caused_ind
-                    granger_sm_single_ind = results_sm[ds][
-                        dt].test_causality(ce, ci)
+                    granger_sm_single_ind = results_sm[ds][dt].test_causality(
+                        ce, ci
+                    )
                     g_t_obt_single = granger_sm_single_ind.test_statistic
-                    assert_allclose(g_t_obt_single, g_t_obt, 1e-07, 0, False,
-                                    err_msg_g_t + " - list of int and int as ".upper() +
-                                    "argument do not yield the same result!".upper())
+                    assert_allclose(
+                        g_t_obt_single,
+                        g_t_obt,
+                        1e-07,
+                        0,
+                        False,
+                        err_msg_g_t
+                        + " - list of int and int as ".upper()
+                        + "argument do not yield the same result!".upper(),
+                    )
 
                 # test p-value for Granger non-causality:
                 g_p_obt = granger_sm_ind.pvalue
-                g_p_des = results_ref[ds][dt]["granger_caus"]["p"][(
-                    causing_key, caused_key)]
-                assert_allclose(g_p_obt, g_p_des, rtol, atol, False, err_msg_g_p)
+                g_p_des = results_ref[ds][dt]["granger_caus"]["p"][
+                    (causing_key, caused_key)
+                ]
+                assert_allclose(
+                    g_p_obt, g_p_des, rtol, atol, False, err_msg_g_p
+                )
                 # check whether string sequences as args work in the same way:
                 g_p_obt_str = granger_sm_str.pvalue
-                assert_allclose(g_p_obt_str, g_p_obt, 1e-07, 0, False,
-                                err_msg_g_t + " - sequences of integers and ".upper() +
-                                "strings as arguments do not yield the same result!".upper())
+                assert_allclose(
+                    g_p_obt_str,
+                    g_p_obt,
+                    1e-07,
+                    0,
+                    False,
+                    err_msg_g_t
+                    + " - sequences of integers and ".upper()
+                    + "strings as arguments do not yield the same result!".upper(),
+                )
                 # check if int (e.g. 0) as index and list of int ([0]) yield
                 # the same result:
                 if len(causing_ind) == 1:
                     g_p_obt_single = granger_sm_single_ind.pvalue
-                    assert_allclose(g_p_obt_single, g_p_obt, 1e-07, 0, False,
-                        err_msg_g_t + " - list of int and int as ".upper() + \
-                                    "argument do not yield the same result!".upper())
+                    assert_allclose(
+                        g_p_obt_single,
+                        g_p_obt,
+                        1e-07,
+                        0,
+                        False,
+                        err_msg_g_t
+                        + " - list of int and int as ".upper()
+                        + "argument do not yield the same result!".upper(),
+                    )
 
                 # test instantaneous causality ################################
                 inst_sm_ind = results_sm[ds][dt].test_inst_causality(
-                    causing_ind)
+                    causing_ind
+                )
                 inst_sm_str = results_sm[ds][dt].test_inst_causality(
-                    causing_names)
+                    causing_names
+                )
                 # test test-statistic for instantaneous non-causality
                 t_obt = inst_sm_ind.test_statistic
-                t_des = results_ref[ds][dt]["inst_caus"][
-                    "test_stat"][(causing_key, caused_key)]
+                t_des = results_ref[ds][dt]["inst_caus"]["test_stat"][
+                    (causing_key, caused_key)
+                ]
                 assert_allclose(t_obt, t_des, rtol, atol, False, err_msg_i_t)
                 # check whether string sequences as args work in the same way:
                 t_obt_str = inst_sm_str.test_statistic
-                assert_allclose(t_obt_str, t_obt, 1e-07, 0, False,
-                                err_msg_i_t + " - sequences of integers and ".upper() +
-                                "strings as arguments do not yield the same result!".upper())
+                assert_allclose(
+                    t_obt_str,
+                    t_obt,
+                    1e-07,
+                    0,
+                    False,
+                    err_msg_i_t
+                    + " - sequences of integers and ".upper()
+                    + "strings as arguments do not yield the same result!".upper(),
+                )
                 # check if int (e.g. 0) as index and list of int ([0]) yield
                 # the same result:
                 if len(causing_ind) == 1:
                     inst_sm_single_ind = results_sm[ds][
-                        dt].test_inst_causality(causing_ind[0])
+                        dt
+                    ].test_inst_causality(causing_ind[0])
                     t_obt_single = inst_sm_single_ind.test_statistic
-                    assert_allclose(t_obt_single, t_obt, 1e-07, 0, False,
-                                    err_msg_i_t + " - list of int and int as ".upper() +
-                                    "argument do not yield the same result!".upper())
+                    assert_allclose(
+                        t_obt_single,
+                        t_obt,
+                        1e-07,
+                        0,
+                        False,
+                        err_msg_i_t
+                        + " - list of int and int as ".upper()
+                        + "argument do not yield the same result!".upper(),
+                    )
 
                 # test p-value for instantaneous non-causality
-                p_obt = results_sm[ds][dt].test_inst_causality(
-                    causing_ind).pvalue
-                p_des = results_ref[ds][dt]["inst_caus"]["p"][(
-                    causing_key, caused_key)]
+                p_obt = (
+                    results_sm[ds][dt].test_inst_causality(causing_ind).pvalue
+                )
+                p_des = results_ref[ds][dt]["inst_caus"]["p"][
+                    (causing_key, caused_key)
+                ]
                 assert_allclose(p_obt, p_des, rtol, atol, False, err_msg_i_p)
                 # check whether string sequences as args work in the same way:
                 p_obt_str = inst_sm_str.pvalue
-                assert_allclose(p_obt_str, p_obt, 1e-07, 0, False,
-                                err_msg_i_p + " - sequences of integers and ".upper() +
-                                "strings as arguments do not yield the same result!".upper())
+                assert_allclose(
+                    p_obt_str,
+                    p_obt,
+                    1e-07,
+                    0,
+                    False,
+                    err_msg_i_p
+                    + " - sequences of integers and ".upper()
+                    + "strings as arguments do not yield the same result!".upper(),
+                )
                 # check if int (e.g. 0) as index and list of int ([0]) yield
                 # the same result:
                 if len(causing_ind) == 1:
                     inst_sm_single_ind = results_sm[ds][
-                        dt].test_inst_causality(causing_ind[0])
+                        dt
+                    ].test_inst_causality(causing_ind[0])
                     p_obt_single = inst_sm_single_ind.pvalue
-                    assert_allclose(p_obt_single, p_obt, 1e-07, 0, False,
-                                    err_msg_i_p + " - list of int and int as ".upper() +
-                                    "argument do not yield the same result!".upper())
+                    assert_allclose(
+                        p_obt_single,
+                        p_obt,
+                        1e-07,
+                        0,
+                        False,
+                        err_msg_i_p
+                        + " - list of int and int as ".upper()
+                        + "argument do not yield the same result!".upper(),
+                    )
 
 
 def test_impulse_response():
@@ -433,9 +553,11 @@ def test_impulse_response():
             periods = 20
             obtained_all = results_sm[ds][dt].irf(periods=periods).irfs
             # flatten inner arrays to make them comparable to parsed results:
-            obtained_all = obtained_all.reshape(periods+1, -1)
+            obtained_all = obtained_all.reshape(periods + 1, -1)
             desired_all = results_ref[ds][dt]["ir"]
-            assert_allclose(obtained_all, desired_all, rtol, atol, False, err_msg)
+            assert_allclose(
+                obtained_all, desired_all, rtol, atol, False, err_msg
+            )
 
 
 def test_lag_order_selection():
@@ -451,10 +573,13 @@ def test_lag_order_selection():
             endog_tot = data[ds]
             exog = generate_exog_from_season(dt[1], len(endog_tot))
             model = VAR(endog_tot, exog)
-            obtained_all = model.select_order(10, trend=dt[0])
+            warn_typ = FutureWarning if dt[0] == "nc" else None
+            with pytest_warns(warn_typ):
+                obtained_all = model.select_order(10, trend=dt[0])
             for ic in ["aic", "fpe", "hqic", "bic"]:
-                err_msg = build_err_msg(ds, dt,
-                                        "LAG ORDER SELECTION - " + ic.upper())
+                err_msg = build_err_msg(
+                    ds, dt, "LAG ORDER SELECTION - " + ic.upper()
+                )
                 obtained = getattr(obtained_all, ic)
                 desired = results_ref[ds][dt]["lagorder"][ic]
                 assert_allclose(obtained, desired, rtol, atol, False, err_msg)
@@ -475,8 +600,11 @@ def test_normality():
             err_msg = build_err_msg(ds, dt, "TEST NON-NORMALITY - STATISTIC")
             obt_statistic = obtained.test_statistic
             des_statistic = results_ref[ds][dt]["test_norm"][
-                "joint_test_statistic"]
-            assert_allclose(obt_statistic, des_statistic, rtol, atol, False, err_msg)
+                "joint_test_statistic"
+            ]
+            assert_allclose(
+                obt_statistic, des_statistic, rtol, atol, False, err_msg
+            )
             err_msg = build_err_msg(ds, dt, "TEST NON-NORMALITY - P-VALUE")
             obt_pvalue = obtained.pvalue
             des_pvalue = results_ref[ds][dt]["test_norm"]["joint_pvalue"]
@@ -500,28 +628,43 @@ def test_whiteness():
 
             obtained = results_sm[ds][dt].test_whiteness(nlags=lags)
             # test statistic
-            err_msg = build_err_msg(ds, dt, "WHITENESS OF RESIDUALS - "
-                                            "TEST STATISTIC")
+            err_msg = build_err_msg(
+                ds, dt, "WHITENESS OF RESIDUALS - " "TEST STATISTIC"
+            )
             desired = results_ref[ds][dt]["whiteness"]["test statistic"]
-            assert_allclose(obtained.test_statistic, desired, rtol, atol, False, err_msg)
+            assert_allclose(
+                obtained.test_statistic, desired, rtol, atol, False, err_msg
+            )
             # p-value
-            err_msg = build_err_msg(ds, dt, "WHITENESS OF RESIDUALS - "
-                                            "P-VALUE")
+            err_msg = build_err_msg(
+                ds, dt, "WHITENESS OF RESIDUALS - " "P-VALUE"
+            )
             desired = results_ref[ds][dt]["whiteness"]["p-value"]
-            assert_allclose(obtained.pvalue, desired, rtol, atol, False, err_msg)
+            assert_allclose(
+                obtained.pvalue, desired, rtol, atol, False, err_msg
+            )
 
-            obtained = results_sm[ds][dt].test_whiteness(nlags=lags,
-                                                         adjusted=True)
+            obtained = results_sm[ds][dt].test_whiteness(
+                nlags=lags, adjusted=True
+            )
             # test statistic (adjusted Portmanteau test)
-            err_msg = build_err_msg(ds, dt, "WHITENESS OF RESIDUALS - "
-                                            "TEST STATISTIC (ADJUSTED TEST)")
+            err_msg = build_err_msg(
+                ds,
+                dt,
+                "WHITENESS OF RESIDUALS - " "TEST STATISTIC (ADJUSTED TEST)",
+            )
             desired = results_ref[ds][dt]["whiteness"]["test statistic adj."]
-            assert_allclose(obtained.test_statistic, desired, rtol, atol, False, err_msg)
+            assert_allclose(
+                obtained.test_statistic, desired, rtol, atol, False, err_msg
+            )
             # p-value (adjusted Portmanteau test)
-            err_msg = build_err_msg(ds, dt, "WHITENESS OF RESIDUALS - "
-                                            "P-VALUE (ADJUSTED TEST)")
+            err_msg = build_err_msg(
+                ds, dt, "WHITENESS OF RESIDUALS - " "P-VALUE (ADJUSTED TEST)"
+            )
             desired = results_ref[ds][dt]["whiteness"]["p-value adjusted"]
-            assert_allclose(obtained.pvalue, desired, rtol, atol, False, err_msg)
+            assert_allclose(
+                obtained.pvalue, desired, rtol, atol, False, err_msg
+            )
 
 
 def test_exceptions():
@@ -537,6 +680,10 @@ def test_exceptions():
 
             # instant causality:
             ### 0<signif<1
-            assert_raises(ValueError, results_sm[ds][dt].test_inst_causality, 0, 0) # this means signif=0
+            assert_raises(
+                ValueError, results_sm[ds][dt].test_inst_causality, 0, 0
+            )  # this means signif=0
             ### causing must be int, str or iterable of int or str
-            assert_raises(TypeError, results_sm[ds][dt].test_inst_causality, [0.5])  # 0.5 not an int
+            assert_raises(
+                TypeError, results_sm[ds][dt].test_inst_causality, [0.5]
+            )  # 0.5 not an int
